@@ -16,7 +16,7 @@ Then you can embed a webview using fltk_webview::Webview::create:
 use fltk::{app, prelude::*, window};
 
 fn main() {
-    let _app = app::App::default();
+    let app = app::App::default();
     let mut win = window::Window::default()
         .with_size(800, 600)
         .with_label("Webview");
@@ -30,8 +30,7 @@ fn main() {
     let mut wv = fltk_webview::Webview::create(false, &mut wv_win);
     wv.navigate("https://google.com");
 
-    // the webview handles the main loop
-    wv.run();
+    app.run().unwrap();
 }
 ```
 
@@ -39,7 +38,7 @@ fn main() {
 - fltk-rs's dependencies, which can be found [here](https://github.com/fltk-rs/fltk-rs#dependencies).
 - On Windows: The necessary shared libraries are automatically provided by the webview-official-sys crate.
 - On MacOS: No dependencies.
-- On Linux, webkit2gtk:
+- On X11/wayland platforms, webkit2gtk:
     - Debian-based distros: `sudo apt-get install libwebkit2gtk-4.0-dev`.
     - RHEL-based distros: `sudo dnf install webkit2gtk3-devel`.
 */
@@ -117,9 +116,9 @@ impl Webview {
                 win.draw(move |w| wv::webview_set_size(inner, w.w(), w.h(), 0));
                 let mut topwin =
                     window::Window::from_widget_ptr(win.top_window().unwrap().as_widget_ptr());
-                topwin.set_callback(|_| {
+                topwin.set_callback(|t| {
                     if app::event() == enums::Event::Close {
-                        std::process::exit(0);
+                        t.hide();
                     }
                 });
             }
@@ -141,14 +140,13 @@ impl Webview {
                     }
                 });
             }
-            #[cfg(target_os = "linux")]
+            #[cfg(not(any(target_os = "macos", target_os = "windows")))] 
             {
-                use std::os::raw::*;
                 pub enum GdkWindow {}
                 pub enum GtkWindow {}
                 pub enum Display {}
                 extern "C" {
-                    pub fn gtk_init(argc: *mut i32, argv: *mut *mut c_char);
+                    pub fn gtk_init(argc: *mut i32, argv: *mut *mut raw::c_char);
                     pub fn my_get_win(wid: *mut GtkWindow) -> *mut GdkWindow;
                     pub fn my_get_xid(w: *mut GdkWindow) -> u64;
                     pub fn x_init(disp: *mut Display, child: u64, parent: u64);
@@ -156,11 +154,14 @@ impl Webview {
                         cb: Option<extern "C" fn(*mut raw::c_void) -> bool>,
                         data: *mut raw::c_void,
                     );
+                    pub fn gtk_main();
+                    pub fn gtk_main_quit();
                 }
                 gtk_init(&mut 0, std::ptr::null_mut());
                 inner = wv::webview_create(debug as i32, std::ptr::null_mut() as _);
                 assert!(!inner.is_null());
                 let temp_win = wv::webview_get_window(inner);
+                assert!(!temp_win.is_null());
                 let temp = my_get_win(temp_win as _);
                 assert!(!temp.is_null());
                 let xid = my_get_xid(temp as _);
@@ -180,11 +181,13 @@ impl Webview {
                     app::check()
                 }
                 g_idle_add(Some(cb), std::ptr::null_mut());
+                app::add_idle(|| gtk_main());
                 let mut topwin =
                     window::Window::from_widget_ptr(win.top_window().unwrap().as_widget_ptr());
-                topwin.set_callback(move |_| {
+                topwin.set_callback(move |t| {
                     if app::event() == enums::Event::Close {
-                        std::process::exit(0);
+                        gtk_main_quit();
+                        t.hide();
                     }
                 });
             }
@@ -278,23 +281,13 @@ impl Webview {
         unsafe { wv::webview_return(*self.inner, seq.as_ptr(), status, result.as_ptr()) }
     }
 
-    /// Run the main loop of the webview
-    pub fn run(&self) {
-        #[cfg(any(target_os = "macos", target_os = "windows"))] 
-        {
-            app::run().unwrap();
-        }
-        #[cfg(not(any(target_os = "macos", target_os = "windows")))] 
-        unsafe { wv::webview_run(*self.inner) }
-    }
-
     /// Set the size of the webview window
     pub fn set_size(&mut self, width: i32, height: i32, hints: SizeHint) {
         unsafe { wv::webview_set_size(*self.inner, width, height, hints as i32) }
     }
 }
 
-#[cfg(target_os = "linux")]
+#[cfg(not(any(target_os = "macos", target_os = "windows")))] 
 fn win_manager(prog: &str) -> bool {
     let sm = std::env::var("SESSION_MANAGER");
     if let Ok(sm) = sm {
